@@ -1,4 +1,4 @@
-//@line 44 "/usr/obj/ports/mozilla-thunderbird-1.5.0.2/mozilla/mail/base/content/mailWindowOverlay.js"
+//@line 44 "/usr/obj/ports/mozilla-thunderbird-1.5.0.4/mozilla/mail/base/content/mailWindowOverlay.js"
 
 const MSG_FLAG_READ              = 0x000001;
 const MSG_FLAG_IMAP_DELETED      = 0x200000;
@@ -2130,7 +2130,9 @@ var gMessageNotificationBar =
       isJunk = ((junkScore != "") && (junkScore != "0"));
     }
 
-    this.updateMsgNotificationBar (isJunk ? kMsgNotificationJunkBar : kMsgNotificationNoStatus);
+    // phishing scams take precedence over junk
+    if (this.mMsgNotificationBar.selectedIndex != kMsgNotificationPhishingBar && isJunk)
+      this.updateMsgNotificationBar (kMsgNotificationJunkBar);
 
     goUpdateCommand('button_junk');
 
@@ -2139,9 +2141,8 @@ var gMessageNotificationBar =
 
   setRemoteContentMsg: function (aMsgHdr)
   {  
-    // The phishing message and junk message takes precedence over the remote content msg
-    if (this.mMsgNotificationBar.selectedIndex != kMsgNotificationJunkBar && 
-        this.mMsgNotificationBar.selectedIndex != kMsgNotificationPhishingBar)
+    // phishing and junk messages take precedence over the remote content msg...
+    if (this.mMsgNotificationBar.selectedIndex == kMsgNotificationNoStatus)
       this.updateMsgNotificationBar(aMsgHdr && aMsgHdr.getUint32Property("remoteContentPolicy") == kBlockRemoteContent ? 
                                     kMsgNotificationRemoteImages : kMsgNotificationNoStatus);
   },
@@ -2159,9 +2160,8 @@ var gMessageNotificationBar =
         return; 
     }
 
-    // The Junk message takes precedence over the phishing message...so skip this step
-    // if the message is already marked as junk
-    if (this.mMsgNotificationBar.selectedIndex != kMsgNotificationJunkBar && isMsgEmailScam(aUrl))
+    // phishing scams take precedence over junk and remote images.
+    if (isMsgEmailScam(aUrl))
       this.updateMsgNotificationBar(kMsgNotificationPhishingBar);
   },
 
